```
dt = 0.01
final_t = 10000
t_steps = int(final_t/dt)
t = np.arange(t_steps)*dt
x = np.zeros(t_steps)
y = np.zeros(t_steps)
sigma = 0.2

for i in tqdm(range(0, t_steps-1)):
    x[i+1] = x[i] - x[i]*dt + np.sqrt(2)*np.random.normal(loc=0.0, scale=1.0)*np.sqrt(dt)
    y[i] = x[i] + sigma*np.random.normal(loc=0.0, scale=1.0)
    
def K(n, x, start, end, binsize, *args, **kwargs):
    ''' returns Kramers-Moyal coefficients for different bins
        default for tau is dt
    '''
    binrange = [int(start/binsize), int(end/binsize)]
    bincount = (binrange[1] - binrange[0]) + 1
    global bins
    bins = np.linspace(start, end, num=bincount) 
    K = []
    
    if 'tau' in kwargs:
        tau = kwargs['tau']
    elif len(args) > 0:
        tau = args[0]
    else:
        tau = dt
    
    for i in range(binrange[0], binrange[1]+1):
        Bin = []
        for j in range(x.size-int(tau/dt)):
            if ((x[j] < float(i)*binsize + binsize/2) & (x[j] > float(i)*binsize - binsize/2)):
                Bin.append(x[j+int(tau/dt)] - x[j])
        Bin = np.array(Bin)
        K.append(np.mean(Bin**n))
    K = np.array(K)
    return K

K_2x = K(n=2, x=x, start=-3, end=3, binsize=0.05, tau=0.01)
K_2y = K(n=2, x=y, start=-3, end=3, binsize=0.05, tau=0.01)
K_1x = K(n=1, x=x, start=-3, end=3, binsize=0.05, tau=0.01)
```